# Trophy case 🏆

`zizmor`'s objective is to detect CI/CD security issues that could compromise
the software we all rely on.

This page documents key examples where `zizmor` helped make big projects more
secure!

!!! tip "Give yourself a trophy!"

    Do you contribute to or maintain a big (>100 star) project that had its GitHub
    Actions security improved by `zizmor`?
    [Add it to our list](./development.md#updating-the-trophy-case)!

<div class="grid cards" markdown>
--8<-- "trophies.md"
</div>

